@@ -67,7 +67,7 @@ with other DBs.
 
 use v5.14;
 
-package SQL::Steno v0.3.1;
+package SQL::Steno v0.3.2;
 
 use utf8;
 use strict;
@@ -140,6 +140,11 @@ sub Query {
 }
 Query ".$_", "   output '&.$_() this' or next query as \U$_", \&set_render
     for keys %render;
+
+Query 'c'.substr( $_, 0, 1 ), "$_   show create (&- or similar for full display)",
+    '&{ $render ||= \&render__create; "" }=show create '.$_.' $1'
+    for qw(table function procedure view);
+
 Query @$_
     for
     ['-' => "   output next query as YAML",
@@ -154,7 +159,8 @@ Query @$_
 
 
     [t => 'unquotedtablename[,unquotedcolumnpattern]   show fields',
-      'COLUMN_NAME,COLUMN_TYPE,IS_NULLABLE NUL,COLUMN_KEY `KEY`,COLUMN_COMMENT;information_schema.`COLUMNS`;TABLE_SCHEMA=schema() and TABLE_NAME=$\1$? and COLUMN_NAME like$\*??:ob ORDINAL_POSITION'],
+      'COLUMN_NAME,COLUMN_TYPE,IS_NULLABLE NUL,COLUMN_KEY `KEY`,COLUMN_COMMENT;information_schema.`COLUMNS`;TABLE_SCHEMA=schema() and TABLE_NAME=$\1:ob ORDINAL_POSITION'],
+#      'COLUMN_NAME,COLUMN_TYPE,IS_NULLABLE NUL,COLUMN_KEY `KEY`,COLUMN_COMMENT;information_schema.`COLUMNS`;TABLE_SCHEMA=schema() and TABLE_NAME=$\1$?>? and COLUMN_NAME like$\>??:ob ORDINAL_POSITION'],
 
 
     [s => 'var;value   set @var = value',
@@ -376,9 +382,10 @@ sub find($$$\%;\@) {
 
 my %rq = ('[', ']',
 	  '{', '}');
-my $quote_re = qr(\\([^\W\d_]*)([-,:;./ #?ω^\\\@!'"`[\]{}]*)(?:%(.+?))?);
-sub quote($$@) {
-    (my $named, local $_, my $join) = splice @_, 0, 3;
+my $quote_re = qr(\\([^\W\d_]*)([-,:;./ #?ω^\\\@!'"`[\]{}]*)(?:%(.+?))?); # $1: name, $2: spec, $3: join
+sub quote($$$$) {
+    local $_ = $_[1];
+    my( $named, undef, $join, @args ) = @_;
     while( $named ) {
 	my $quotes = $Quotes{$named};
 	if( !defined $quotes or "\\$quotes" !~ /^$quote_re$/o ) {
@@ -391,8 +398,9 @@ sub quote($$@) {
 	$join //= $3;
     }
     $join //= ',';
-    return join $join, @_ unless defined;
-    my @args = @_;
+    my $list = ref $args[0];
+    @args = @{$args[0]} if $list;
+    return join $join, @args unless defined;
     /(['"`[{])/;
     my( $lq ) = /(['"`[{])/;
     $lq ||= "'";
@@ -402,8 +410,8 @@ sub quote($$@) {
     my $split = tr/-// ? '-' : ''; # avoid range by putting - 1st
     $split .= tr/ // ? '\s' : '';  # space means any whitespace
     $split .= join '', /([,:;.\/])/g;
-    $split ||= ',';
-    $split = $space ? qr/[$split]/ : qr/\s*[$split]\s*/;
+    $split ||= ',' unless $list;
+    $split &&= $space ? qr/[$split]/ : qr/\s*[$split]\s*/;
     join $join, map {
 	if( $noquote || $boolean && /^(?:true|false)$/i || $null && /^null$/i || $var && /^\@\w+$/ ) {
 	    $_;
@@ -418,7 +426,7 @@ sub quote($$@) {
 	    s/\A\s*//;
 	    s/\s*\Z//;
 	}
-	split $split, $_, -1;
+	$split ? split $split, $_, -1 : $_;
     } @args;
 }
 
@@ -435,7 +443,7 @@ sub convert_Query($$) {
     return &$res( $name, @arg ) // '' if $ref;
 
     my( @var, %seen, @rest );
-    $res =~ s(\$$quote_re?(?:(\d+\b)|([*>_]))) {
+    $res =~ s(\$$quote_re?(?:(\d+\b)|([*>_]))) { # $4: numbered arg, $5: special arg
 	if( $4 && $4 > @arg ) {
 	    '';
 	} else {
@@ -452,8 +460,8 @@ sub convert_Query($$) {
     $res =~ s(\cV(\d+)\cZ) {
 	my @res = @{$var[$1]};
 	quote $res[0], $res[1], $res[2],
-	    $res[4] ? ($res[4] eq '*' ? @arg :
-		       $res[4] eq '>' ? @rest :
+	    $res[4] ? ($res[4] eq '*' ? \@arg :
+		       $res[4] eq '>' ? \@rest :
 		       $_) :
 	    $res[3] < 0 ? $name : $arg[$res[3]];
     }eg;
@@ -505,7 +513,12 @@ whitespace of both ends of the resulting strings.
 =item C<,> (comma), the default
 
 You only need to specify it, if you want to split on commas, as well as other
-characters, at the same time.
+characters, at the same time.  Where the C<\> (backslash) syntax is also used,
+when given a list, there is no default splitting of list members:
+L<C<:\{I<Perl
+code>}>|/Perl-code-or-:-namespec-Perl-code-or-:-namespec-join-Perl-code> and
+L<canned query's|/query-arg-...-or-query-arg-...-following-text> C<$\*> &
+C<$\E<gt>>.  In that case you must specify it, if needed, e.g. C<$\,*>.
 
 =item C<E<nbsp>> (space)
 
@@ -639,9 +652,14 @@ set C<$weekstart> to not follow ISO 8601 and the bible).
 =back
 
 
-=head3 C<:{I<Perl code>}>
+=head3 C<:{I<Perl code>}> E<nbsp> or E<nbsp> C<:\I<namespec>{I<Perl code>}> E<nbsp> or E<nbsp> C<:\I<namespec>%I<join>{I<Perl code>}>
 
-This gets replaced by what it returns.
+This gets replaced by what it returns in list context.  Undefined elements get
+rendered as C<NULL> and they all get joined by I<join> or else C<,> (comma).
+They can become quoted like
+L<C<:\>|/namespec-strings-or-:-namespec-join-strings>.  Since the result is
+already a list, the elements don't get split by default.  If you want that,
+you must specify it as in C<:\,{I<Perl code>}>.
 
 
 =head3 C<#I<tbl>> E<nbsp> or E<nbsp> C<#I<tbl>#> E<nbsp> or E<nbsp> C<#I<tbl>#I<alias>>
@@ -691,38 +709,50 @@ are frst replaced by C<set> and then C<where>.
 =cut
 
 sub convert {
-    # Handle :\...(str1, str2, str3)
-    s<(?:\b(\w+)|:)$quote_re\((.+?)\)> {
-	($1 ? "$1(" : '') .
- 	quote( $2, $3, $4, $5 ) .
-	($1 ? ')' : '')
-    }ge;
     my @strings;		# extract strings to prevent following replacements inside.
-    while( /\G.*?(['"`[{])/gc ) {
-	my $rq = $rq{$1}||$1;
-	my $pos = pos;
-	while( /\G.*?([$rq\\])/gc ) {
-	    if( $1 eq '\\' ) {
-		++pos;		# skip next
-	    } elsif( ! /\G$rq/gc ) { # skip doubled quote
-		push @strings,
-		    substr $_, $pos - 1, 1 - $pos + pos, # get string
-		    "\cS".@strings."\cZ"; # and replace with counter
-		last;
+    until( $error ) {
+	# Handle :\...{perl}
+	next if
+	    s(:$quote_re?$perl_re){
+		my @ret = map $_ // 'NULL', eval substr $4, 1, -1; # strip {}
+		$error = 1, warn $@ if $@;
+		quote $1, $2, $3, \@ret;
+	    }ego
+
+	# Handle function\...(str1, str2, str3) and :\...(str1, str2, str3)
+	or
+	    s<(?:\b(\w+)|:)$quote_re\((.+?)\)> {
+		($1 ? "$1(" : '') .
+		quote( $2, $3, $4, $5 ) .
+		($1 ? ')' : '')
+	    }ge;
+
+	# extract quoted strings
+	while( /\G.*?(['"`[{])/gc ) {
+	    my $rq = $rq{$1}||$1;
+	    my $pos = pos;
+	    while( /\G.*?([$rq\\])/gc ) {
+		if( $1 eq '\\' ) {
+		    ++pos;		# skip next
+		} elsif( ! /\G$rq/gc ) { # skip doubled quote
+		    push @strings,
+			substr $_, $pos - 1, 1 - $pos + pos, # get string
+			"\cS".@strings."\cZ"; # and replace with counter
+		    last;
+		}
 	    }
 	}
+
+	# \todo (?(?<=\w)\b)
+	next if
+	    s&:($timespec_re[+-]\d*$timespec_re(?(?<=\w)\b)|l?j\w+(?:#(\w*))|\w+)&find $1, ':', '', %Macros&ego;
+	last;
     }
 
-    until( $error ) {
-	s&:$perl_re&my $ret = eval $1; warn $@ if $@; $ret // ' NULL '&ego or
-	    # \todo (?(?<=\w)\b)
-	    s&:($timespec_re[+-]\d*$timespec_re(?(?<=\w)\b)|l?j\w+(?:#(\w*))|\w+)&find $1, ':', '', %Macros&ego or
-		last;
-    }
-
-    s&^(?=#)&;&;		# Assume empty fieldlist before table name
+    my $was_column = /^\./ or	# Avoid next assumption when 1st column name is also a table name.
+	s&^(?=#)&;&;		# Assume empty fieldlist before table name
     &convert_table_column;
-    s&^(?=$table_re)&;&;	# Assume empty fieldlist before table name
+    s&^(?=$table_re)&;& unless $was_column; # Assume empty fieldlist before table name
 
     s&\b(\w+)\((?=\s*([,)])?)&my $fn = find $1, '', '(', %Functions, @Functions; ($fn || $1).'('.($2 and $DefaultArguments{$1} || $DefaultArguments{$fn} or '')&eg unless $error;
     #s&\b(\w+)(?=\()&find $1, '', '(', %Functions, @Functions or $1&eg unless $error;
@@ -939,7 +969,7 @@ sub render_yaml($;$$) {
 		s/^/    /mg;
 		substr $_, 0, 0, $nl ? "|2\n" : "|2-\n";
 	    }
-	    printf "$label[$i++]$_\n" if @label;
+	    print "$label[$i++]$_\n" if @label;
 	}
 	if( @label ) {
 	    defined count or last if defined $count;
@@ -963,6 +993,17 @@ sub render_yaml($;$$) {
     }
 }
 
+sub render__create($;$$) {
+    my @row = $_[0]->fetchrow_array
+	or return;
+    my $col = $_[0]{NAME}[0] =~ /Function|Procedure/i ? 2 : 1;
+    if( @row > $col ) {
+	$col = $row[$col];
+	$col =~ s/,/,\n/g if $_[0]{NAME}[0] =~ /View/i;
+	say $col;
+    }
+}
+
 
 
 my $lasttime = time;
@@ -1034,8 +1075,9 @@ C<$\I<namespec>I<arg>> or C<$\I<namespec>%I<join>I<arg>>.  Here I<arg> is
 C<*>, C<E<gt>> or a number directly tacked on to I<spec> or I<join>.  E.g.:
 C<$\-"1> splits the 1st (semi-colon separated from the 2nd) argument itself on
 C<-> (minus), quotes the pieces with C<"> (double quote) and joins them with
-C<,> (comma).  Putting the quotes inside the argument like this, eliminates
-them, if no argument is given.
+C<,> (comma).  The two list variables C<$\*> & C<$\E<gt>> don't get split
+individually unless explicitly specified, e.g. C<$\,*>.  Putting the quotes
+inside the argument like this, eliminates them, if no argument is given.
 
 =head3 C</I<regexp>/ I<statement>> E<nbsp> or E<nbsp> C</I<regexp>/i I<statement>> E<nbsp> or E<nbsp> C<!/I<regexp>/ I<statement>> E<nbsp> or E<nbsp> C<!/I<regexp>/i I<statement>>
 
@@ -1086,7 +1128,7 @@ or where the conversion doesn't play well with your intention.
 Help prefix.  Alone it will give an overview.  You can follow up with any of
 the special syntaxes, with or without an abbreviation.  E.g. C<?(> will show
 all function abbreviations, whereas C<?I<abbrev>(> will show only those functions
-matching abbrev or C<?#I<abbrev>> only those tables matching abbrev.
+matching I<abbrev> or C<?#I<abbrev>> only those tables matching I<abbrev>.
 
 =head3 C<??I<statement>>
 
